@@ -10,6 +10,7 @@ __all__ = [
     "DataObserverBase",
     "ChangePointDetectorBase",
     "TimeSeriesForecasterBase",
+    "ClassifierBase",
 ]
 
 from .fileops import *
@@ -20,6 +21,7 @@ from .feature_compute import *
 from .metrics import *
 from .anomalies import *
 from .changepoints import *
+from .classifier import *
 from .timeseries_forecaster import *
 from .synthetic_data_generator import *
 from .observability import *
