@@ -857,14 +857,18 @@ class AnomaliesBase(Compute):
                 extra={"transform": self.name, "data": msg}
             )
         else:
-            logger.exception(
+            logger.error(
                 f"Could not load profilespec",
                 extra={"transform": self.name, "data": msg}
             )
             raise Exception("could not load profilespec")
 
+        specs = profile.get("specs", None)
+        if specs is None:
+            raise Exception("Could not find 'specs' in profile")
+
         # Now go through each spec and generate anomaly reports
-        for spec in profile:
+        for spec in specs:
 
             ## first, some checks on the spec
             do_process_spec = True
