@@ -772,7 +772,7 @@ class ChangePointDetectorBase(Compute):
     def get_datewindow(self, source, spec):
         datewindow = {}
         default_delta = 180
-        
+
         start_date_str = source.get('start_date')
         end_date_str = source.get('end_date')
 
@@ -834,14 +834,18 @@ class ChangePointDetectorBase(Compute):
                 extra={"transform": self.name, "data": msg}
             )
         else:
-            logger.exception(
+            logger.error(
                 f"Could not load profilespec",
                 extra={"transform": self.name, "data": msg}
             )
             raise Exception("could not load profilespec")
 
+        specs = profile.get("specs", None)
+        if specs is None:
+            raise Exception("Could not find 'specs' in profile")
+
         # Now go through each spec and process it
-        for spec in profile:
+        for spec in specs:
 
             ## first, some checks on the spec
             do_process_spec = True
