@@ -21,6 +21,7 @@ from functools import partial
 
 logger = logging.getLogger("app")
 
+from enrichsdk.contrib.lib.assets import profilespec
 from enrichsdk.utils import get_lineage_of_query
 from enrichsdk.lib.exceptions import NoDataFound
 
@@ -114,51 +115,6 @@ class MetricsBase(Compute):
         """
         return {}
 
-    def get_profile(self):
-        """
-        Read the profile json
-        """
-
-        if (not hasattr(self, "profiledir")) and (not hasattr(self, "profilefile")):
-            raise Exception(
-                "'profiledir' transform attribute should be defined to use default get_profile method"
-            )
-
-        paths = []
-        if hasattr(self, "profilefile"):
-            paths.append(self.profilefile)
-
-        if hasattr(self, "profiledir"):
-            paths.extend(
-                [
-                    self.profiledir + "/profile.json",
-                    self.profiledir + "/profile.yaml",
-                    self.profiledir + "/profilespec.json",
-                    self.profiledir + "/profilespec.yaml",
-                ]
-            )
-
-        profile = None
-        for p in paths:
-            if not os.path.exists(p):
-                continue
-            if p.endswith(".json"):
-                profile = json.load(open(p))
-            elif p.endswith(".yaml"):
-                profile = yaml.load(open(p))
-
-        if profile is None:
-            raise Exception("Profile could not be found")
-
-        sources = profile["sources"]
-        specs = profile["specs"]
-        logger.debug(
-            f"Found {len(sources)} sources {len(specs)} specs",
-            extra={"transform": self.name, "data": json.dumps(profile, indent=4)},
-        )
-
-        return profile
-
     def get_specs(self, profile):
         if (not isinstance(profile, dict)) or ("specs" not in profile):
             raise Exception("Specs not defined in profile")
@@ -572,7 +528,19 @@ class MetricsBase(Compute):
         # Will be used in other places..
         self.state = state
 
-        profile = self.get_profile()
+        # Get the profile spec
+        is_valid, profile, msg = profilespec.get_profile(self, None)
+        if is_valid:
+            logger.debug(
+                f"Loaded profilespec",
+                extra={"transform": self.name, "data": msg}
+            )
+        else:
+            logger.error(
+                f"Could not load profilespec",
+                extra={"transform": self.name, "data": msg}
+            )
+            raise Exception("could not load profilespec")
 
         # Get specs..
         specs = self.get_specs(profile)
