@@ -858,17 +858,21 @@ class DataObserverBase(Compute):
                 extra={"transform": self.name, "data": msg}
             )
         else:
-            logger.exception(
+            logger.error(
                 f"Could not load profilespec",
                 extra={"transform": self.name, "data": msg}
             )
             raise Exception("could not load profilespec")
 
+        specs = profile.get("specs", None)
+        if specs is None:
+            raise Exception("Could not find 'specs' in profile")
+
         # get the dataset lookup table
-        customer_datasets = profilespec.construct_dataset_list(self, profile)
+        customer_datasets = profilespec.construct_dataset_list(self, specs)
 
         # Now go through each spec and process it
-        for spec in profile:
+        for spec in specs:
 
             ## first, some checks on the spec
             do_process_spec = True
