@@ -647,18 +647,17 @@ class SyntheticDataGeneratorBase(Compute):
                 extra={"transform": self.name, "data": msg}
             )
         else:
-            logger.exception(
+            logger.error(
                 f"Could not load profilespec",
                 extra={"transform": self.name, "data": msg}
             )
             raise Exception("could not load profilespec")
 
-
         # get the dataset lookup table
         customer_datasets = profilespec.construct_dataset_list(self, profile)
 
         # Now go through each dataset and generate synthetic data for it
-        for spec in profile:
+        for spec in specs:
 
             process_spec = True
 
@@ -673,7 +672,7 @@ class SyntheticDataGeneratorBase(Compute):
 
             for f in ["name", "config"]:
                 if f not in spec:
-                    logger.exception(
+                    logger.error(
                         f"Spec has no {f} param set, skipping.",
                         extra={"transform": self.name, "data": json.dumps(spec, indent=4)}
                     )
