@@ -60,7 +60,7 @@ class RunBase(object):
             raise Exception("Could not locate metadata.json")
 
         statinfo = os.stat(metadatapath)
-        if statinfo.st_size > 1024 * 1024:  # 1MB
+        if statinfo.st_size > 5*1024 * 1024:  # 1MB
             raise Exception("Metadata file size too large")
 
         metadata = json.loads(open(metadatapath).read())
@@ -91,6 +91,7 @@ class RunBase(object):
         self.stats = metadata["stats"]
         self.pid = metadata.get("pid", None)
         self.cmdline = metadata.get("cmdline", [])
+        self.kpi = metadata.get('kpi',{})
         self.lineage = []
 
         # Patch for backward compatability
