@@ -52,6 +52,8 @@ def send_html_email(content, sender, receivers, subject, attachments=[], reply_t
     msg = MIMEMultipart()
     msg.attach(MIMEText(content, "html"))
 
+    if isinstance(receivers, str):
+        receivers = [receivers]
 
     msg["From"] = sender
     msg["To"] = ", ".join(receivers)
